@@ -3,7 +3,7 @@ package fa_code_demo;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright (C) 2000-2015  Brian M. Kelly
+#    Copyright (C) 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -51,6 +51,8 @@ $test=1; # comment-out this line for Production mode
 #----------  TEST PARAMETERS  ----------------
 
 our $build_type= $test ? 'test' : '';
+our $toggle_rootdir= $build_type ? 'tmp' : 'usr'; 
+our $toggle_staticdir= $build_type ? 'tmp' : 'webfs';
 
 #---------------------------------------------
 
@@ -58,26 +60,30 @@ our $build_type= $test ? 'test' : '';
 $timeout=90;
 ##############################################
 
-############  SET TOSSPASS  ##################
-#$tosspass=1;
+######## SET PASSWORD FILE LOCATION  #########
+if ($^O eq 'cygwin') {
+   $passwd_file_loc="/passwds_ms";
+} else {
+   $passwd_file_loc="/passwds_ux"
+}
 ##############################################
 
 #####  SET EMAIL AUTOMATION SETTINGS  ########
 %email_addresses=(
-   'bkelly' => 'Brian.Kelly@fullautosoftware.net',
+   'bkelly' => 'Brian.Kelly@fullauto.com',
 );
 my $email_to=[
-               #']USERNAME[',
-               #'Brian.Kelly@fullautosoftware.net',
+               ']USERNAME[',
+               'Brian.Kelly@fullauto.com',
              ];
-%email_defaults=(
-   #Usage       => 'notify_on_error',
-   Mail_Method => 'smtp',
-   Mail_Server => '',
-   #Reply_To    => 'Brian.Kelly@bcbsa.com',
-   #To          => $email_to,
-   #From        => "$progname\@fullautosoftware.net"
-);
+#%email_defaults=(
+#   Usage       => 'notify_on_error',
+#   Mail_Method => 'smtp',
+#   Mail_Server => 'mailserver.fullauto.com',
+#   Reply_To    => 'Brian.Kelly@fullauto.com',
+#   To          => $email_to,
+#   From        => "$progname\@fullauto.com"
+#);
 ##############################################
 
 ##  -------------------------------------------------------------
@@ -90,97 +96,135 @@ sub hello_world {
 
 }
 
-sub image_magick {
+sub hello_world_old {
 
-   # Check for installation
-   our $path='';my ($key,$status)=('','');
-   ($path,$key,$status)=&persist_get('image_magick_path');
-   if ($status=~/DB_NOTFOUND: No matching key\/data pair found/ or !$path) {
-      #Look for installation
-      my ($stdout,$stderr)=$localhost->cmd("which convert");
-      if (-1<index $stdout,'convert') {
-         my ($stdout_ver,$stderr)=$localhost->cmd("\"$stdout\" -version");
-         if (-1<index $stdout_ver,'ImageMagick') {
-            $path=$stdout;
-            $status=persist_put($key,$path);
-         }
-      }
-      unless ($path) {
-         if ($^O eq 'cygwin') {
-            if (-f '/usr/bin/convert.exe') {
-               $path='/usr/bin/convert.exe';
-            } elsif (-f '/bin/convert.exe') {
-               $path='/usr/bin/convert.exe';
-            } elsif (-f '/usr/local/bin/convert.exe') {
-               $path='/usr/local/bin/convert.exe';
-            }
-            $status=persist_put($key,$path) if $path;
-         } else {
-            if (-f '/usr/bin/convert') {
-               $path='/usr/bin/convert';
-            } elsif (-f '/bin/convert') {
-               $path='/usr/bin/convert';
-            } elsif (-f '/usr/local/bin/convert') {
-               $path='/usr/local/bin/convert';
-            }
-            $status=persist_put($key,$path) if $path;
-         }
-      }
-      unless ($path) {
-         print "\n\n       INFO: FullAuto needs to do a one time ",
-               " Search for ImageMagick.\n             This may ",
-               "take a few minutes. Future invocations\n       ",
-               "      will not require this search.\n\n";
-         require File::Find;
-         do { 
-            sub Wanted {
-               return if $path;
-               /.cpan/ and $File::Find::prune = 1;
-               return if -d;
-               if (/^convert(.exe)*$/) {
-                  my $out=`$File::Find::name -version 2>&1`;
-                  if (-1<index $out,'ImageMagick') {
-                     $path=$File::Find::name;
-                  }
-               }
-            }
-            my @dirs=();
-            push @dirs,('/usr');
-            push @dirs,('/opt') if -d '/opt';
-            push @dirs,(getpwuid $>)[7];
-            File::Find::find(\&Wanted,@dirs);
-         };
-         $status=persist_put($key,$path);
-      }
-   }
-   print "\n\n   PATH=$path\n";
-   my $image_fax_viewer='cmd /c C:\\\\WINDOWS\\\\System32\\\\rundll32.exe '.
-         'C:\\\\WINDOWS\\\\System32\\\\shimgvw.dll,ImageView_Fullscreen '.
-         'C:\\\\cygwin\\\\fullauto\\\\FullAuto\\\\lib\\\\Net\\\\FullAuto'.
-         '\\\\Distro\\\\fullautologo.jpg &';
-   `$image_fax_viewer`;
+    #print "\nFIRST PARAMETER=$_[0]\n";
+    #print "SECOND PARAMETER=$_[1]\n";
+    my $hostname=$localhost->cmd('hostname');
+    my $stdout='';
+    my $stderr='';
+    my $computer_zero='';
+    my $computer_one='';
+    ($computer_zero,$stderr)=connect_host('Zero'); # Connect to
+                                        # Remote Host via ssh
+    if ($stderr) {
+       print "We Have an ERROR when attempting to connect to Zero! : $stderr\n";
+    }
+
+    if ($hostname eq 'bkelly-laptop') {
+       $computer_one=connect_ssh('VB_Ubuntu'); # Connect to
+                                            # Remote Host via ssh
+    } else {
+       $computer_one=connect_host('Ubuntu'); # Connect to
+                                            # Remote Host via ssh
+    }
+    print "\nHELLO=",$localhost->cmd('echo "hello world"'),"\n";
+    print "HOSTNAME=$hostname\n";
+    print "HELLO WORLD\n";
+    ($stdout,$stderr)=$computer_one->cmd('hostname');
+    print "Ubuntu=$stdout\n";
+    ($stdout,$stderr)=$computer_zero->cmd('hostname');
+    print "Zero=$stdout\n\n";
+    ($stdout,$stderr)=$computer_zero->cwd('/develop/deployment/dest');
+    print "STDERR=$stderr<==\n" if $stderr;
+    my $file='';
+    ($file,$stderr)=$computer_zero->cmd('ls ID*');
+    print "Zero File=$file<==\n\n";
+    return unless $file;
+    ($stdout,$stderr)=$computer_zero->get($file); # Get the File
+    if ($stderr) {                                # Check Results
+       print "We Have an ERROR! : $stderr\n";
+    }
+    ($stdout,$stderr)=$computer_one->cwd('/home/qa/import');
+    print "STDERR=$stderr\n" if $stderr;
+    ($stdout,$stderr)=$computer_one->put($file); # Get the File
+    if ($stderr) {                               # Check Results
+       print "We Have an ERROR! : $stderr\n";
+    }
+    ($stdout,$stderr)=$computer_one->cmd('ls');
+    print $computer_one->{_hostlabel}->[0]," ls output:\n\n$stdout\n";
+    ($stdout,$stderr)=$computer_one->cmd('pwd');
+    print "CURDIR=$stdout\n\n" if $stdout;
 
 }
 
-sub test_email {
+sub figlet_fonts {
 
-       my %mail=(
-          'To'      => [ 'Brian.Kelly@bcbsa.com' ],
-          'From'    => 'brian.kelly@fullautosoftware.net',
-          'Body'    => "\nFullAuto ERROR =>\n\n"."HA HA".
-                       "       in fa_code.pm Line ".__LINE__,
-          'Subject' => "FullAuto ERROR Encountered When Connecting to NOWHERE",
-       );
-       my $ignore='';my $emerr='';
-       ($ignore,$emerr)=&send_email(\%mail);
-       if ($emerr) {
-          die "\n\nEMAIL ERROR =>$emerr<==\n\n";
-       } else {
-          return;
-       }
+   Net::FullAuto::FA_Core::figlet();
 
 }
 
+sub menu_demo {
+
+   my @list=`ls -1 /bin`;
+   my %Menu_1=(
+
+      Item_1 => {
+
+         Text    => "/bin Utility - ]Convey[",
+         Convey  => [ `ls -1 /bin` ],
+
+      },
+
+      Select => 'Many',
+      Banner => "\n   Choose a /bin Utility :\n\n"
+   );
+
+   my @selections=&Menu(\%Menu_1,$unattended);
+   print "\nSELECTIONS = @selections\n";
+
+}
+
+sub howdy_world {
+   open (FH,">FullAuto_howdy_world.txt");
+   FH->autoflush(1);
+   my $cnt=0;
+   while (1) {
+      print FH $cnt++;
+#      sleep 2;
+      last if $cnt==20;
+   }
+   #----------------------------------------------
+   # Connect to Remote Host with *BOTH* ssh & sftp
+   #----------------------------------------------
+   my ($host,$stderr)=('','');
+   my $hostname=`hostname`;
+   chomp $hostname;
+   my $hostlab='Laptop';
+   if ($hostname eq 'opensolaris') {
+      ($host,$stderr)=connect_secure('Laptop');
+   } elsif ($hostname eq 'reedfish-laptop') {
+      ($host,$stderr)=connect_secure('Laptop');
+   } else {
+      $hostlab='Solaris';
+      ($host,$stderr)=connect_secure('Solaris');
+   }
+   if ($stderr) {
+      print "       We Have an ERROR when attempting to connect ",
+            "to Ubuntu! :\n$stderr       in fa_code.pm ",
+            "Line ",__LINE__,"\n";
+      my %mail=(
+         'To'      => [ 'Brian.Kelly@bcbsa.com' ],
+         'From'    => 'Brian.Kelly@fullauto.com',
+         'Body'    => "\nFullAuto ERROR =>\n\n".$stderr.
+                      "       in fa_code.pm Line ".__LINE__,
+         'Subject' => "FullAuto ERROR Encountered When Connecting to Ubuntu",
+      );
+      my $ignore='';my $emerr='';
+      ($ignore,$emerr)=&send_email(\%mail);
+      if ($emerr) {
+         die "\n\n       $stderr\n       EMAIL ERROR =>$emerr<==\n\n";
+      } else {
+         #die $stderr;
+         return;
+      }
+   }
+   print "LOGIN SUCCESSFUL\n";
+   print FH "LOGIN SUCCESSFUL ",`date`,"\n";
+   close FH;
+   &cleanup();
+}
+
 sub compare_fa_code {
 
    my ($solaris_ssh,$solaris_sftp,$laptop_sftp,$output,$stderr)=
@@ -240,77 +284,6 @@ sub compare_fa_code {
    print "STDERR=$stderr\n" if $stderr;
 }
 
-sub howdy_world {
-   open (FH,">FullAuto_howdy_world.txt");
-   FH->autoflush(1);
-   my $cnt=0;
-   while (1) {
-      print FH $cnt++;
-#      sleep 2;
-      last if $cnt==20;
-   }
-   #----------------------------------------------
-   # Connect to Remote Host with *BOTH* ssh & sftp
-   #----------------------------------------------
-   my ($host,$stderr)=('','');
-   my $hostname=`hostname`;
-   chomp $hostname;
-   my $hostlab='Laptop';
-   if ($hostname eq 'opensolaris') {
-      ($host,$stderr)=connect_secure('Laptop');
-   } elsif ($hostname eq 'reedfish-laptop') {
-      ($host,$stderr)=connect_secure('Laptop');
-   } else {
-      $hostlab='Solaris';
-      ($host,$stderr)=connect_secure('Solaris');
-   }
-   if ($stderr) {
-      print "       We Have an ERROR when attempting to connect ",
-            "to Ubuntu! :\n$stderr       in fa_code.pm ",
-            "Line ",__LINE__,"\n";
-      my %mail=(
-         'To'      => [ 'Brian.Kelly@bcbsa.com' ],
-         'From'    => 'Brian.Kelly@fullautosoftware.net',
-         'Body'    => "\nFullAuto ERROR =>\n\n".$stderr.
-                      "       in fa_code.pm Line ".__LINE__,
-         'Subject' => "FullAuto ERROR Encountered When Connecting to Ubuntu",
-      );
-      my $ignore='';my $emerr='';
-      ($ignore,$emerr)=&send_email(\%mail);
-      if ($emerr) {
-         die "\n\n       $stderr\n       EMAIL ERROR =>$emerr<==\n\n";
-      } else {
-         #die $stderr;
-         return;
-      }
-   }
-   print "LOGIN SUCCESSFUL\n";
-   print FH "LOGIN SUCCESSFUL ",`date`,"\n";
-   close FH;
-   &cleanup();
-}
-
-sub menu_demo {
-
-   my @list=`ls -1 /bin`;
-   my %Menu_1=(
-
-      Item_1 => {
-
-         Text    => "/bin Utility - ]Convey[",
-         Convey  => [ `ls -1 /bin` ],
-
-      },
-
-      Select => 'Many',
-      Banner => "\n   Choose a /bin Utility :\n\n"
-   );
-
-   my @selections=&Menu(\%Menu_1,$unattended);
-   print "\nSELECTIONS = @selections\n";
-
-}
-
 sub remote_hostname {
 
     my ($computer_one,$stdout,$stderr);      # Scope Variables
