@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::OpenLDAP_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2016  Brian M. Kelly
+#    Copyright © 2000-2015  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -205,7 +205,7 @@ END
    my $master=$main::aws->{$server_type}->[$cnt]->[0]->{InstanceId};
    $c="aws ec2 describe-instances --instance-ids $master 2>&1";
    my ($hash,$output,$error)=('','','');
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    my $mdns=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicDnsName};
    my $pbip=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicIpAddress};
    my $dcnt=0;
@@ -244,7 +244,7 @@ END
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
@@ -277,32 +277,32 @@ my $standup_openldap=sub {
    my $c='aws ec2 describe-security-groups '.
          "--group-names $n";
    my ($hash,$output,$error)=('','','');
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error;
    my $cidr=$hash->{SecurityGroups}->[0]->{IpPermissions}
             ->[0]->{IpRanges}->[0]->{CidrIp};
    $c='aws ec2 create-security-group --group-name '.
       'OpenLDAPSecurityGroup --description '.
       '"OpenLDAP.org Security Group" 2>&1';
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name OpenLDAPSecurityGroup --protocol '.
       'tcp --port 22 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name OpenLDAPSecurityGroup --protocol '.
       'tcp --port 80 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name OpenLDAPSecurityGroup --protocol '.
       'tcp --port 443 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    my $cnt=0;
