@@ -478,8 +478,12 @@ print "DOING NGINX\n";
    $ad="%NL%".
        "%NL%            include fastcgi_params;".
        "%NL%            fastcgi_pass  localhost:3003;%NL%%NL%";
-   ($stdout,$stderr)=$handle->cmd("sed -i \'/location/i$ad\' ".
-      "/usr/local/nginx/nginx.conf");
+   $ad=<<END;
+sed -i '1,/location/ {/location/a\
+$ad
+}' /usr/local/nginx/nginx.conf
+END
+   ($stdout,$stderr)=$handle->cmd($ad);
    $ad='%NL%        location /static {'.
        '%NL%            root /home/Administrator/FullAutoAPI/root;'.
        '%NL%        }%NL%%NL%';
@@ -1164,6 +1168,18 @@ END
            '__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING FCGI::ProcManager
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan FCGI::ProcManager",
+           '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING Catalyst::Helper::Model::DBIC::Schema
@@ -1502,7 +1518,7 @@ END
       "./script/fullautoapi_create.pl controller User",'__display__');
    ($stdout,$stderr)=$handle->cmd("mv lib/FullAutoAPI/Controller/User.pm ".
       "lib/FullAutoAPI/Controller/User.bak");
-   my $view_path='./FullAutoAPI/View/TT.pm';
+   my $view_path='./lib/FullAutoAPI/View/TT.pm';
    ($stdout,$stderr)=$handle->cmd(
       "./script/fullautoapi_create.pl view TT TT",'__display__');
    $ad='    WRAPPER => %SQ%wrapper.tt%SQ%,%NL%';
